PSAURON
===========

![License](https://img.shields.io/badge/license-MIT-blue.svg "License")

**PSAURON** is a machine learning model for rapid assessment of protein coding gene annotation. Link to paper coming soon...

Installation
------------------

Pip Installation:

```bash
$ pip install psauron
